Module compression_static

Module compression_static 

Compression static module to serve compressed files directly from the file system.

Structs

CompressedFileVariant
It defines the pre-compressed file variant metadata of a particular file path.

Functions

init
Initializes static compression.
precompressed_variant
Search for the pre-compressed variant of the given file path.