pub struct RouterService { /* private fields */ }Expand description
It defines the router service which is the main entry point for Hyper Server.
Implementations
Sourceimpl RouterService
impl RouterService
Sourcepub fn new(handler: RequestHandler) -> Self
pub fn new(handler: RequestHandler) -> Self
Creates a new router service.
Sourcepub fn build(&self, remote_addr: Option<SocketAddr>) -> RequestService
pub fn build(&self, remote_addr: Option<SocketAddr>) -> RequestService
Build a new request service for an accepted connection.