static_web_server::settings

Module cli

The server CLI options.

Structs

  • General server configuration available in CLI and config file options.

Enums

  • Subcommands for additional maintenance tasks, like installing and uninstalling the SWS Windows Service and generation of completions and man pages