pub fn build_placeholder_replacer(regex: &Regex) -> AhoCorasickExpand description
Build an AhoCorasick automaton for the placeholder patterns $0, $1, …, $N
based on the number of capture groups in the given regex.
pub fn build_placeholder_replacer(regex: &Regex) -> AhoCorasickBuild an AhoCorasick automaton for the placeholder patterns $0, $1, …, $N
based on the number of capture groups in the given regex.