Module static_web_server::signals
source · Expand description
The module provides signals support like SIGTERM, SIGINT and SIGQUIT.
Functions
- It creates a common list of signals stream for
SIGTERM,SIGINTandSIGQUITto be observed. - It waits for a specific type of incoming signals included
ctrl+c.